@@ -37,7 +37,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("AddSmsSign", params)
+            headers = request.headers
+            body = self.call("AddSmsSign", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.AddSmsSignResponse()
@@ -66,7 +67,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("AddSmsTemplate", params)
+            headers = request.headers
+            body = self.call("AddSmsTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.AddSmsTemplateResponse()
@@ -94,7 +96,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CallbackStatusStatistics", params)
+            headers = request.headers
+            body = self.call("CallbackStatusStatistics", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CallbackStatusStatisticsResponse()
@@ -122,7 +125,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteSmsSign", params)
+            headers = request.headers
+            body = self.call("DeleteSmsSign", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteSmsSignResponse()
@@ -150,7 +154,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteSmsTemplate", params)
+            headers = request.headers
+            body = self.call("DeleteSmsTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteSmsTemplateResponse()
@@ -178,7 +183,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeSmsSignList", params)
+            headers = request.headers
+            body = self.call("DescribeSmsSignList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeSmsSignListResponse()
@@ -206,7 +212,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeSmsTemplateList", params)
+            headers = request.headers
+            body = self.call("DescribeSmsTemplateList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeSmsTemplateListResponse()
@@ -236,7 +243,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifySmsSign", params)
+            headers = request.headers
+            body = self.call("ModifySmsSign", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifySmsSignResponse()
@@ -266,7 +274,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifySmsTemplate", params)
+            headers = request.headers
+            body = self.call("ModifySmsTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifySmsTemplateResponse()
@@ -294,7 +303,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("PullSmsReplyStatus", params)
+            headers = request.headers
+            body = self.call("PullSmsReplyStatus", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.PullSmsReplyStatusResponse()
@@ -322,7 +332,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("PullSmsReplyStatusByPhoneNumber", params)
+            headers = request.headers
+            body = self.call("PullSmsReplyStatusByPhoneNumber", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.PullSmsReplyStatusByPhoneNumberResponse()
@@ -350,7 +361,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("PullSmsSendStatus", params)
+            headers = request.headers
+            body = self.call("PullSmsSendStatus", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.PullSmsSendStatusResponse()
@@ -378,7 +390,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("PullSmsSendStatusByPhoneNumber", params)
+            headers = request.headers
+            body = self.call("PullSmsSendStatusByPhoneNumber", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.PullSmsSendStatusByPhoneNumberResponse()
@@ -407,7 +420,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SendSms", params)
+            headers = request.headers
+            body = self.call("SendSms", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SendSmsResponse()
@@ -435,7 +449,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SendStatusStatistics", params)
+            headers = request.headers
+            body = self.call("SendStatusStatistics", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SendStatusStatisticsResponse()
@@ -463,7 +478,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SmsPackagesStatistics", params)
+            headers = request.headers
+            body = self.call("SmsPackagesStatistics", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SmsPackagesStatisticsResponse()
